@@ -1,8 +1,7 @@
-from pynonymizer.database.provider import SEED_TABLE_NAME
 from tqdm import tqdm
 from time import sleep
-from pynonymizer import log
-from pynonymizer.database.provider import DatabaseProvider
+import logging
+from pynonymizer.database.provider import DatabaseProvider, SEED_TABLE_NAME
 from pynonymizer.database.exceptions import UnsupportedTableStrategyError
 from pynonymizer.database.mysql import execution, query_factory
 from pynonymizer.database.basic.input import resolve_input
@@ -18,18 +17,30 @@ class MySqlProvider(DatabaseProvider):
     """
     __CHUNK_SIZE = 8192
     __DUMPSIZE_ESTIMATE_INFLATION = 1.15
-    logger = log.get_logger(__name__)
+    logger = logging.getLogger(__name__)
 
-    def __init__(self, db_host, db_user, db_pass, db_name, db_port=None, seed_rows=None, dump_opts=None):
+    def __init__(self, db_host, db_user, db_pass, db_name, db_port=None, seed_rows=None, cmd_opts=None, dump_opts=None):
         if db_host is None:
             db_host = "127.0.0.1"
         if db_port is None:
             db_port = "3306"
+        if cmd_opts is None:
+            cmd_opts = ""
         if dump_opts is None:
             dump_opts = ""
 
-        super().__init__(db_host=db_host, db_user=db_user, db_pass=db_pass, db_name=db_name, db_port=db_port, seed_rows=seed_rows)
-        self.__runner = execution.MySqlCmdRunner(db_host, db_user, db_pass, db_name, db_port)
+        self.db_host = db_host
+        self.db_user = db_user
+        self.db_pass = db_pass
+        self.db_name = db_name
+        self.db_port = db_port
+
+        if seed_rows is None:
+            seed_rows = 150
+
+        self.seed_rows = int(seed_rows)
+
+        self.__runner = execution.MySqlCmdRunner(db_host, db_user, db_pass, db_name, db_port, additional_opts=cmd_opts)
         self.__dumper = execution.MySqlDumpRunner(db_host, db_user, db_pass, db_name, db_port, additional_opts=dump_opts)
 
     def __seed(self, qualifier_map):
@@ -59,7 +70,7 @@ class MySqlProvider(DatabaseProvider):
 
     def __run_scripts(self, script_list, title=""):
         for i, script in enumerate(script_list):
-            self.logger.info(f"Running f{title} script #{i} \"{script[:50]}\"")
+            self.logger.info(f"Running {title} script #{i} \"{script[:50]}\"")
             self.logger.info(self.__runner.db_execute(script))
 
     def create_database(self):
