@@ -1,5 +1,4 @@
 from pynonymizer.strategy.exceptions import UnknownColumnStrategyError, UnknownTableStrategyError, ConfigSyntaxError
-from pynonymizer.log import get_logger
 from pynonymizer.strategy.table import UpdateColumnsTableStrategy, TruncateTableStrategy, DeleteTableStrategy, TableStrategyTypes
 from pynonymizer.strategy.update_column import (
     UpdateColumnStrategyTypes,
@@ -11,8 +10,9 @@ from pynonymizer.strategy.update_column import (
 )
 from pynonymizer.strategy.database import DatabaseStrategy
 from copy import deepcopy
+import logging
 
-logger = get_logger(__name__)
+logger = logging.getLogger(__name__)
 
 
 class StrategyParser:
@@ -63,6 +63,11 @@ class StrategyParser:
                 return {
                     "type": UpdateColumnStrategyTypes.UNIQUE_LOGIN.value
                 }
+            elif column_config.startswith("(") and column_config.endswith(")"):
+                return {
+                    "type": UpdateColumnStrategyTypes.LITERAL.value,
+                    "value": column_config
+                }
 
             else:
                 # Can't match it to anything special, must be a fake_update type. move the value to the fake_type field
